#
# users.py - Handles logins and other user interaction
#
# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Tim Flink <tflink@redhat.com>
#
# Liberally borrows from the sample app in Flask-FAS maintained by Ian Weller

from functools import wraps

from flask import redirect, url_for, request, g, abort

from blockerbugs import app, fas

@app.route('/auth_login')
def auth_login():
    if 'next' in request.args:
        next_url = request.args['next']
    else:
        next_url = url_for('main.index')
    return fas.login(return_url=next_url)


@app.route('/auth_logout')
def auth_logout():
    if g.fas_user:
        app.logger.info('Logging out user %s' % g.fas_user.username)
        fas.logout()
    else:
        app.logger.debug('No FAS user to logout')
    return redirect(url_for('main.index'))


def check_admin_rights():
    if g.fas_user is None:
        return fas.login()
    else:
        for group in g.fas_user.approved_memberships:
            if group.name == app.config['FAS_ADMIN_GROUP']:
                return None
        app.logger.info('Failed admin access to %s by %s' % (
            request.url, g.fas_user.username))
        abort(401)
