#
# build.py - ORM class for build information stored in the database
#
# Copyright 2013, Red Hat, Inc
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Authors:
#   Tim Flink <tflink@redhat.com>
#   Ilgiz Islamgulov <ilgizisl@gmail.com>
#
from sqlalchemy.schema import UniqueConstraint
import koji

from blockerbugs import db
from blockerbugs.util.koji_interface import get_build_data

build_spins = db.Table(
    'build_spins',
    db.Column('spin_id', db.Integer, db.ForeignKey('spin.id')),
    db.Column('build_id', db.Integer, db.ForeignKey('build.koji_id'))
)


class Build(db.Model):
    koji_id = db.Column(db.Integer, primary_key=True)
    spins = db.relationship('Spin', secondary=build_spins,
                            backref='builds')
    pkg_name = db.Column(db.Text)
    version = db.Column(db.Text)
    release = db.Column(db.Text)
    nvr = db.Column(db.Text, unique=True)
    epoch = db.Column(db.Integer, nullable=True)

    __table_args__ = (UniqueConstraint('pkg_name', 'version', 'release',
                                       name='build_pkg_ver_rel'), )

    def __unicode__(self):
        return 'build: %s' % (self.nvr)

    @classmethod
    def from_nvr(cls, nvr, spins=None):
        data = get_build_data(nvr)
        exists_build = Build.query.get(data['build_id'])
        if exists_build is not None:
            raise koji.GenericError(u'Build already exists.')
        build = Build()
        build.koji_id = data['build_id']
        build.epoch = data['epoch']
        build.pkg_name = data['name']
        build.release = data['release']
        build.version = data['version']
        build.nvr = '{b.pkg_name}-{b.version}-{b.release}'.format(b=build)
        if spins is not None:
            build.spins = spins
        db.session.add(build)
        db.session.commit()
